@@ -1,3 +1,11 @@
+#!/usr/bin/env python2.7
+
+try:
+  activate_this = './bin/activate_this.py'
+  execfile(activate_this, dict(__file__=activate_this))
+except:
+  pass
+
 import click
 import sys
 from sqlalchemy import *
